Class: Google::Cloud::Logging::V2::LoggingService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/logging/v2/logging_service/client.rb

Overview

Client for the LoggingService service.

Service for ingesting and querying logs.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#billing_account_path, #folder_path, #log_path, #organization_path, #project_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new LoggingService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Logging::V2::LoggingService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Logging::V2::LoggingService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the LoggingService client.

Yield Parameters:



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 154

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/logging/v2/logging_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @logging_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Logging::V2::LoggingServiceV2::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @logging_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the LoggingService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all LoggingService clients
::Google::Cloud::Logging::V2::LoggingService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Logging", "V2"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.delete_log.timeout = 60.0
    default_config.rpcs.delete_log.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.write_log_entries.timeout = 60.0
    default_config.rpcs.write_log_entries.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.list_log_entries.timeout = 60.0
    default_config.rpcs.list_log_entries.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.list_monitored_resource_descriptors.timeout = 60.0
    default_config.rpcs.list_monitored_resource_descriptors.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.list_logs.timeout = 60.0
    default_config.rpcs.list_logs.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config.rpcs.tail_log_entries.timeout = 3600.0
    default_config.rpcs.tail_log_entries.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 13, 14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the LoggingService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:



124
125
126
127
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 124

def configure
  yield @config if block_given?
  @config
end

#delete_log(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_log(log_name: nil) ⇒ ::Google::Protobuf::Empty

Deletes all the log entries in a log for the _Default Log Bucket. The log reappears if it receives new entries. Log entries written shortly before the delete operation might not be deleted. Entries received after the delete operation with a timestamp before the operation will be deleted.

Examples:

Basic example

require "google/cloud/logging/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Logging::V2::LoggingService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Logging::V2::DeleteLogRequest.new

# Call the delete_log method.
result = client.delete_log request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_log(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_log via a request object, either of type DeleteLogRequest or an equivalent Hash.

  • #delete_log(log_name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_log via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 275

def delete_log request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Logging::V2::DeleteLogRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_log..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Logging::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.log_name
    header_params["log_name"] = request.log_name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_log.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_log.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @logging_service_stub.call_rpc :delete_log, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_log_entries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Logging::V2::LogEntry> #list_log_entries(resource_names: nil, filter: nil, order_by: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Logging::V2::LogEntry>

Lists log entries. Use this method to retrieve log entries that originated from a project/folder/organization/billing account. For ways to export log entries, see Exporting Logs.

Examples:

Basic example

require "google/cloud/logging/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Logging::V2::LoggingService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Logging::V2::ListLogEntriesRequest.new

# Call the list_log_entries method.
result = client.list_log_entries request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Logging::V2::LogEntry.
  p item
end

Overloads:

  • #list_log_entries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Logging::V2::LogEntry>

    Pass arguments to list_log_entries via a request object, either of type Google::Cloud::Logging::V2::ListLogEntriesRequest or an equivalent Hash.

  • #list_log_entries(resource_names: nil, filter: nil, order_by: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Logging::V2::LogEntry>

    Pass arguments to list_log_entries via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 556

def list_log_entries request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Logging::V2::ListLogEntriesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_log_entries..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Logging::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_log_entries.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_log_entries.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @logging_service_stub.call_rpc :list_log_entries, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @logging_service_stub, :list_log_entries, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_logs(request, options = nil) ⇒ ::Google::Cloud::Logging::V2::ListLogsResponse #list_logs(parent: nil, resource_names: nil, page_size: nil, page_token: nil) ⇒ ::Google::Cloud::Logging::V2::ListLogsResponse

Lists the logs in projects, organizations, folders, or billing accounts. Only logs that have entries are listed.

Examples:

Basic example

require "google/cloud/logging/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Logging::V2::LoggingService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Logging::V2::ListLogsRequest.new

# Call the list_logs method.
result = client.list_logs request

# The returned object is of type Google::Cloud::Logging::V2::ListLogsResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 756

def list_logs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Logging::V2::ListLogsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_logs..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Logging::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_logs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_logs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @logging_service_stub.call_rpc :list_logs, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_monitored_resource_descriptors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Api::MonitoredResourceDescriptor> #list_monitored_resource_descriptors(page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Api::MonitoredResourceDescriptor>

Lists the descriptors for monitored resource types used by Logging.

Examples:

Basic example

require "google/cloud/logging/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Logging::V2::LoggingService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Logging::V2::ListMonitoredResourceDescriptorsRequest.new

# Call the list_monitored_resource_descriptors method.
result = client.list_monitored_resource_descriptors request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Api::MonitoredResourceDescriptor.
  p item
end

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 646

def list_monitored_resource_descriptors request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Logging::V2::ListMonitoredResourceDescriptorsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_monitored_resource_descriptors..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Logging::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_monitored_resource_descriptors.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_monitored_resource_descriptors.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @logging_service_stub.call_rpc :list_monitored_resource_descriptors, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @logging_service_stub, :list_monitored_resource_descriptors, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.



210
211
212
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 210

def logger
  @logging_service_stub.logger
end

#tail_log_entries(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Logging::V2::TailLogEntriesResponse>

Streaming read of log entries as they are ingested. Until the stream is terminated, it will continue reading logs.

Examples:

Basic example

require "google/cloud/logging/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Logging::V2::LoggingService::Client.new

# Create an input stream.
input = Gapic::StreamInput.new

# Call the tail_log_entries method to start streaming.
output = client.tail_log_entries input

# Send requests on the stream. For each request object, set fields by
# passing keyword arguments. Be sure to close the stream when done.
input << Google::Cloud::Logging::V2::TailLogEntriesRequest.new
input << Google::Cloud::Logging::V2::TailLogEntriesRequest.new
input.close

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::Logging::V2::TailLogEntriesResponse
output.each do |current_response|
  p current_response
end

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 838

def tail_log_entries request, options = nil
  unless request.is_a? ::Enumerable
    raise ::ArgumentError, "request must be an Enumerable" unless request.respond_to? :to_enum
    request = request.to_enum
  end

  request = request.lazy.map do |req|
    ::Gapic::Protobuf.coerce req, to: ::Google::Cloud::Logging::V2::TailLogEntriesRequest
  end

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.tail_log_entries..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Logging::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.tail_log_entries.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.tail_log_entries.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @logging_service_stub.call_rpc :tail_log_entries, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain



134
135
136
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 134

def universe_domain
  @logging_service_stub.universe_domain
end

#write_log_entries(request, options = nil) ⇒ ::Google::Cloud::Logging::V2::WriteLogEntriesResponse #write_log_entries(log_name: nil, resource: nil, labels: nil, entries: nil, partial_success: nil, dry_run: nil) ⇒ ::Google::Cloud::Logging::V2::WriteLogEntriesResponse

Writes log entries to Logging. This API method is the only way to send log entries to Logging. This method is used, directly or indirectly, by the Logging agent (fluentd) and all logging libraries configured to use Logging. A single request may contain log entries for a maximum of 1000 different resources (projects, organizations, billing accounts or folders)

Examples:

Basic example

require "google/cloud/logging/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Logging::V2::LoggingService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Logging::V2::WriteLogEntriesRequest.new

# Call the write_log_entries method.
result = client.write_log_entries request

# The returned object is of type Google::Cloud::Logging::V2::WriteLogEntriesResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/google/cloud/logging/v2/logging_service/client.rb', line 433

def write_log_entries request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Logging::V2::WriteLogEntriesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.write_log_entries..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Logging::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.write_log_entries.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.write_log_entries.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @logging_service_stub.call_rpc :write_log_entries, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end